OiRA

# Certificate

This certificate is presented to

Sacrebleu & Fils European Trucking Ltd.

For conducting a risk assessment with the tool “Transport routier” on 7 September 2019.

Departement/Region SIRET number Contact name

Your certificate for “Buckets and broomsticks” is publically visible on the OiRA website.

Copy the following link to anyone to whom it may concern as proof that you've conducted this risk assessment.

https://oiraproject.eu/en/certificates/9879809808
Prenta

Back

## certificate-public-published.html

Meira

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More